@@ -477,7 +477,7 @@ def fis_bs_funnel(labels, values, opacity_ins=0.5):
                     textposition = "inside",
                     textinfo = "value+percent initial",
                     opacity=opacity_ins,
-                    marker = {"color": color_rgb,}
+                    marker = {"color": color_node,}
                             ),
     layout=layout)
     
